==========
I18N-UTILS
==========

.. image:: https://img.shields.io/travis/GaretJax/i18n-utils.svg
   :target: https://travis-ci.org/GaretJax/i18n-utils

.. image:: https://img.shields.io/pypi/v/i18n-utils.svg
   :target: https://pypi.python.org/pypi/i18n-utils

.. image:: https://img.shields.io/coveralls/GaretJax/i18n-utils/develop.svg
   :target: https://coveralls.io/r/GaretJax/i18n-utils?branch=develop

.. image:: https://img.shields.io/badge/docs-latest-brightgreen.svg
   :target: http://i18n-utils.readthedocs.org/en/latest/

.. image:: https://img.shields.io/pypi/l/i18n-utils.svg
   :target: https://github.com/GaretJax/i18n-utils/blob/develop/LICENSE

.. image:: https://img.shields.io/requires/github/GaretJax/i18n-utils.svg 
   :target: https://requires.io/github/GaretJax/i18n-utils/requirements/?branch=master


* Free software: MIT license
* Documentation: http://i18n-utils.rtfd.org
